" plugin/sessx.vim
"
" SessX - Richard Bentley-Green, 27/04/2020
"
" Simple session management
"
if exists('g:Sessx_loaded')
  finish
endif
let g:Sessx_loaded = 1

" ----------------------------------
" This is a non-standard colour
highlight default link StatusMsg Normal

" Print a 'status' message to the command line
function s:PrintStatusMsg(msg)
  echohl StatusMsg | echo a:msg | echohl None
endfunction

" Print a 'warning' message to the command line
function s:PrintWarningMsg(msg)
  echohl WarningMsg | echo a:msg | echohl None
endfunction

" ----------------------------------
" Before anything else happens, record the startup working directory.
" This is used to ensure any session files are saved in a known place
let s:StartupWD = getcwd()
if s:StartupWD == ''
  call s:PrintWarningMsg("BAD STARTUP DIRECTORY - SessX plugin partially disabled\n")
  call getchar()
endif

" Automate saving session on exit (if one exists)
" Note: This also saves the SelX configuration if defined
function s:SaveSession()
  if v:this_session != ""
    call inputsave()
    echohl Question
    let ans = input('Save session "'.v:this_session.'" ? : ')
    echohl None
    call inputrestore()
    if ((ans == 'y') || (ans == 'Y'))
      exe 'mksession! '.v:this_session
      call selx#SelXSave(v:this_session, 1)
    endif
  endif
endfunction

autocmd VimLeave * call s:SaveSession()

" Save/create session in home/startup directory. A name may (optionally) be provided
" Note: This also saves the SelX configuration if defined
function s:MkSession(...)
  if !a:0 && (v:this_session != '')
    exe 'mksession! '.v:this_session
    if exists('g:Selx_loaded')
      call selx#SelXSave(v:this_session, 1)
    endif
    call s:PrintStatusMsg('Saved session - ' . v:this_session)
  elseif s:StartupWD != ''
    let l:name='/Session.vim'
    if a:0
      let l:name='/Session_'.a:1.'.vim'
    endif
    exe 'mksession! '.s:StartupWD.l:name
    if exists('g:Selx_loaded')
      call selx#SelXSave(s:StartupWD.l:name, 1)
    endif
    call s:PrintStatusMsg('Created new session - ' . v:this_session)
  else
    call s:PrintWarningMsg('Bad startup directory - Cannot create new session')
  endif
endfunction

command -nargs=* MKS call s:MkSession(<f-args>)

function s:MkSessionInfo()
  if v:this_session != ''
    call s:PrintStatusMsg('Current session: ' . v:this_session)
  else
    call s:PrintStatusMsg('No active session')
  endif
endfunction

command -nargs=* MKSInfo call s:MkSessionInfo()

" ------------------------------------------------------------------------------
" eof

